@@ -1,5 +1,3 @@
-use crate::{generate_local_apub_endpoint, EndpointType};
-use anyhow::anyhow;
 use itertools::Itertools;
 use lemmy_apub_lib::{
   object_id::ObjectId,
@@ -11,15 +9,15 @@ use lemmy_utils::{
   LemmyError,
 };
 use lemmy_websocket::LemmyContext;
-use log::debug;
 use serde::{Deserialize, Serialize};
+use tracing::debug;
 use url::Url;
 
 #[derive(Serialize, Deserialize, Debug)]
 pub struct WebfingerLink {
   pub rel: Option<String>,
-  #[serde(rename(serialize = "type", deserialize = "type"))]
-  pub type_: Option<String>,
+  #[serde(rename = "type")]
+  pub kind: Option<String>,
   pub href: Option<Url>,
 }
 
@@ -29,39 +27,10 @@ pub struct WebfingerResponse {
   pub links: Vec<WebfingerLink>,
 }
 
-/// Takes in a shortname of the type dessalines@xyz.tld or dessalines (assumed to be local), and
-/// outputs the actor id. Used in the API for communities and users.
-///
-/// TODO: later provide a method in ApubObject to generate the endpoint, so that we dont have to
-///       pass in EndpointType
-pub async fn webfinger_resolve<Kind>(
-  identifier: &str,
-  endpoint_type: EndpointType,
-  context: &LemmyContext,
-  request_counter: &mut i32,
-) -> Result<DbUrl, LemmyError>
-where
-  Kind: ApubObject<DataType = LemmyContext> + ActorType + Send + 'static,
-  for<'de2> <Kind as ApubObject>::ApubType: serde::Deserialize<'de2>,
-{
-  // remote actor
-  if identifier.contains('@') {
-    webfinger_resolve_actor::<Kind>(identifier, context, request_counter).await
-  }
-  // local actor
-  else {
-    let domain = context.settings().get_protocol_and_hostname();
-    Ok(generate_local_apub_endpoint(
-      endpoint_type,
-      identifier,
-      &domain,
-    )?)
-  }
-}
-
 /// Turns a person id like `@name@example.com` into an apub ID, like `https://example.com/user/name`,
 /// using webfinger.
-async fn webfinger_resolve_actor<Kind>(
+#[tracing::instrument(skip_all)]
+pub(crate) async fn webfinger_resolve_actor<Kind>(
   identifier: &str,
   context: &LemmyContext,
   request_counter: &mut i32,
@@ -81,6 +50,11 @@ where
   );
   debug!("Fetching webfinger url: {}", &fetch_url);
 
+  *request_counter += 1;
+  if *request_counter > context.settings().http_fetch_retry_limit {
+    return Err(LemmyError::from_message("Request retry limit reached"));
+  }
+
   let response = retry(|| context.client().get(&fetch_url).send()).await?;
 
   let res: WebfingerResponse = response
@@ -91,17 +65,27 @@ where
   let links: Vec<Url> = res
     .links
     .iter()
-    .filter(|l| l.type_.eq(&Some("application/activity+json".to_string())))
+    .filter(|link| {
+      if let Some(type_) = &link.kind {
+        type_.starts_with("application/")
+      } else {
+        false
+      }
+    })
     .map(|l| l.href.clone())
     .flatten()
     .collect();
   for l in links {
     let object = ObjectId::<Kind>::new(l)
-      .dereference(context, request_counter)
+      .dereference(context, context.client(), request_counter)
       .await;
     if object.is_ok() {
       return object.map(|o| o.actor_id().into());
     }
   }
-  Err(anyhow!("Failed to resolve actor for {}", identifier).into())
+  let error = LemmyError::from(anyhow::anyhow!(
+    "Failed to resolve actor for {}",
+    identifier
+  ));
+  Err(error.with_message("failed_to_resolve"))
 }
