@@ -11,8 +11,13 @@ use crate::http::{
   person::{get_apub_person_http, get_apub_person_outbox, person_inbox},
   post::get_apub_post,
   shared_inbox,
+  site::{get_apub_site_http, get_apub_site_inbox, get_apub_site_outbox},
+};
+use actix_web::{
+  guard::{Guard, GuardContext},
+  http::{header, Method},
+  web,
 };
-use actix_web::{dev::RequestHead, guard::Guard, http::Method, *};
 use http_signature_normalization_actix::digest::middleware::VerifyDigest;
 use lemmy_utils::settings::structs::Settings;
 use sha2::{Digest, Sha256};
@@ -22,6 +27,8 @@ pub fn config(cfg: &mut web::ServiceConfig, settings: &Settings) {
     println!("federation enabled, host is {}", settings.hostname);
 
     cfg
+      .route("/", web::get().to(get_apub_site_http))
+      .route("/site_outbox", web::get().to(get_apub_site_outbox))
       .route(
         "/c/{community_name}",
         web::get().to(get_apub_community_http),
@@ -53,7 +60,8 @@ pub fn config(cfg: &mut web::ServiceConfig, settings: &Settings) {
         .guard(InboxRequestGuard)
         .route("/c/{community_name}/inbox", web::post().to(community_inbox))
         .route("/u/{user_name}/inbox", web::post().to(person_inbox))
-        .route("/inbox", web::post().to(shared_inbox)),
+        .route("/inbox", web::post().to(shared_inbox))
+        .route("/site_inbox", web::post().to(get_apub_site_inbox)),
     );
   }
 }
@@ -64,15 +72,12 @@ pub fn config(cfg: &mut web::ServiceConfig, settings: &Settings) {
 struct InboxRequestGuard;
 
 impl Guard for InboxRequestGuard {
-  fn check(&self, request: &RequestHead) -> bool {
-    if request.method != Method::POST {
+  fn check(&self, ctx: &GuardContext) -> bool {
+    if ctx.head().method != Method::POST {
       return false;
     }
-    if let Some(val) = request.headers.get("Content-Type") {
-      return val
-        .to_str()
-        .expect("Content-Type header contains non-ascii chars.")
-        .starts_with("application/");
+    if let Some(val) = ctx.head().headers.get(header::CONTENT_TYPE) {
+      return val.as_bytes().starts_with(b"application/");
     }
     false
   }
