@@ -2,7 +2,7 @@ use crate::{
   fetcher::post_or_comment::PostOrComment,
   mentions::Mention,
   objects::{comment::ApubComment, person::ApubPerson, post::ApubPost},
-  protocol::{Source, Unparsed},
+  protocol::Source,
 };
 use activitystreams_kinds::object::NoteType;
 use chrono::{DateTime, FixedOffset};
@@ -12,6 +12,7 @@ use lemmy_db_schema::{newtypes::CommentId, source::post::Post, traits::Crud};
 use lemmy_utils::LemmyError;
 use lemmy_websocket::LemmyContext;
 use serde::{Deserialize, Serialize};
+use serde_json::Value;
 use serde_with::skip_serializing_none;
 use std::ops::Deref;
 use url::Url;
@@ -29,16 +30,15 @@ pub struct Note {
   #[serde(deserialize_with = "crate::deserialize_one_or_many")]
   pub(crate) cc: Vec<Url>,
   pub(crate) content: String,
+  pub(crate) in_reply_to: ObjectId<PostOrComment>,
+
   pub(crate) media_type: Option<MediaTypeHtml>,
   #[serde(default)]
   pub(crate) source: SourceCompat,
-  pub(crate) in_reply_to: ObjectId<PostOrComment>,
   pub(crate) published: Option<DateTime<FixedOffset>>,
   pub(crate) updated: Option<DateTime<FixedOffset>>,
   #[serde(default)]
   pub(crate) tag: Vec<Mention>,
-  #[serde(flatten)]
-  pub(crate) unparsed: Unparsed,
 }
 
 /// Pleroma puts a raw string in the source, so we have to handle it here for deserialization to work
@@ -46,9 +46,9 @@ pub struct Note {
 #[serde(rename_all = "camelCase")]
 #[serde(untagged)]
 pub(crate) enum SourceCompat {
-  None,
   Lemmy(Source),
-  Pleroma(String),
+  Other(Value),
+  None,
 }
 
 impl Default for SourceCompat {
@@ -67,7 +67,7 @@ impl Note {
     let parent = Box::pin(
       self
         .in_reply_to
-        .dereference(context, request_counter)
+        .dereference(context, context.client(), request_counter)
         .await?,
     );
     match parent.deref() {
